bayespy.inference.vmp.nodes.gaussian.GaussianGammaARDToGaussianWishart.__init__
===============================================================================

.. currentmodule:: bayespy.inference.vmp.nodes.gaussian

.. automethod:: GaussianGammaARDToGaussianWishart.__init__